@@ -30,15 +30,25 @@ class Data:
     def __init__(self,
                  x: Union[torch.Tensor, torch_geometric.data.Data],
                  y: float = None,
+                 idx: int = None,
                  dtype: str = DTYPE_FVEC):
         self.x = deepcopy(x)
         self.y = None if y is None else torch.tensor(y, dtype=torch.float)
+        self.__idx = idx
         self.__dtype = dtype
 
+    @property
+    def idx(self):
+        return self.__idx
+
     @property
     def dtype(self):
         return self.__dtype
 
+    @property
+    def tooltip(self):
+        return 'Data index: ' + str(self.idx)
+
 
 class Dataset(torch.utils.data.Dataset):
     """
@@ -106,6 +116,10 @@ class Dataset(torch.utils.data.Dataset):
     def dtype(self):
         return self.__dtype
 
+    @property
+    def tooltips(self):
+        return [d.tooltip for d in self.data]
+
     def clone(self,
               x: list = None) -> Dataset:
         """
